Index: content/renderer/p2p/ipc_socket_factory.h |
diff --git a/content/renderer/p2p/ipc_socket_factory.h b/content/renderer/p2p/ipc_socket_factory.h |
index 53e1edc2feabc7868fe6d196d40d8bfb31ae2d81..cba98b3c0d060c452a178ade4da5434a213bfef8 100644 |
--- a/content/renderer/p2p/ipc_socket_factory.h |
+++ b/content/renderer/p2p/ipc_socket_factory.h |
@@ -14,33 +14,33 @@ namespace content { |
class P2PSocketDispatcher; |
-// IpcPacketSocketFactory implements rtc::PacketSocketFactory |
+// IpcPacketSocketFactory implements talk_base::PacketSocketFactory |
// interface for libjingle using IPC-based P2P sockets. The class must |
// be used on a thread that is a libjingle thread (implements |
// rtc::Thread) and also has associated base::MessageLoop. Each |
// socket created by the factory must be used on the thread it was |
// created on. |
-class IpcPacketSocketFactory : public rtc::PacketSocketFactory { |
+class IpcPacketSocketFactory : public talk_base::PacketSocketFactory { |
public: |
CONTENT_EXPORT explicit IpcPacketSocketFactory( |
P2PSocketDispatcher* socket_dispatcher); |
virtual ~IpcPacketSocketFactory(); |
- virtual rtc::AsyncPacketSocket* CreateUdpSocket( |
- const rtc::SocketAddress& local_address, |
+ virtual talk_base::AsyncPacketSocket* CreateUdpSocket( |
+ const talk_base::SocketAddress& local_address, |
int min_port, int max_port) OVERRIDE; |
- virtual rtc::AsyncPacketSocket* CreateServerTcpSocket( |
- const rtc::SocketAddress& local_address, |
+ virtual talk_base::AsyncPacketSocket* CreateServerTcpSocket( |
+ const talk_base::SocketAddress& local_address, |
int min_port, |
int max_port, |
int opts) OVERRIDE; |
- virtual rtc::AsyncPacketSocket* CreateClientTcpSocket( |
- const rtc::SocketAddress& local_address, |
- const rtc::SocketAddress& remote_address, |
- const rtc::ProxyInfo& proxy_info, |
+ virtual talk_base::AsyncPacketSocket* CreateClientTcpSocket( |
+ const talk_base::SocketAddress& local_address, |
+ const talk_base::SocketAddress& remote_address, |
+ const talk_base::ProxyInfo& proxy_info, |
const std::string& user_agent, |
int opts) OVERRIDE; |
- virtual rtc::AsyncResolverInterface* CreateAsyncResolver() OVERRIDE; |
+ virtual talk_base::AsyncResolverInterface* CreateAsyncResolver() OVERRIDE; |
private: |
P2PSocketDispatcher* socket_dispatcher_; |
@@ -14,33 +14,33 @@ namespace content { |
// interface for libjingle using IPC-based P2P sockets. The class must |
// be used on a thread that is a libjingle thread (implements |
-// rtc::Thread) and also has associated base::MessageLoop. Each |
+// talk_base::Thread) and also has associated base::MessageLoop. Each |
// socket created by the factory must be used on the thread it was |
// created on. |